      program make_input

      implicit NONE

      integer NBODMAX
      parameter (NBODMAX=201)

      integer nbod,ialpha,i,j,k,iseed
      real*8 ran3
      real*8 dpi,deg,msun,gm,au,t
      real*8 radius,rhill,sema,ecc,inc,capom,omega,capm
      real*8 x,y,z,vx,vy,vz
      real*8 me,totmass,multiple,factor,rho
      real*8 tot,a_,mass_,q,q_
      real*8 mass(NBODMAX),a(NBODMAX),elmts(NBODMAX,6)

      dpi=acos(-1.d0)
      deg=dpi/180.d0
      msun=39.47841760d0  ! GM, au/y
      me=3.d-6*msun
      au=1.496d11  ! m
      rho = 3.0d3  ! kg m^-3

c input
      read(*,*,err=990,end=990) iseed
      iseed = -iseed

c read initial conditions
      open(unit=10,file='10My.out',status='old')
      j = 0
20    continue
        j = j+1
        if (j.gt.NBODMAX) then
          write(*,*) 'Error: j = NBODMAX = ', NBODMAX
          stop
        endif
        read(10,*,err=30,end=30) i,t,(elmts(j,k),k=1,6),mass(j)
      goto 20
30    continue
      nbod = j-1

c Sun
      write(*,*) nbod+3
      write(*,8488) msun
 8488 format(3(1x,g20.10))    
      write(*,*) '0.0 0.0 0.0'
      write(*,*) '0.0 0.0 0.0'      

c protoplanets
      do j=1,nbod
        sema=elmts(j,1)
        rhill=sema*(mass(j)/(3.d0*msun))**(1.d0/3.d0)
        radius=(mass(j)/msun*2.d30/(4.d0/3.d0*dpi*rho))**(1.d0/3.d0)/au
        write(0,*) 'sema = ', sema, ' au'
c        write(0,*) 'mass = ', mass(j)/me, ' M_E'
c        write(0,*) 'radius = ', radius, ' au = ', radius*au/1.e3, ' km'
        ecc=elmts(j,2)
        inc=elmts(j,3)*deg
        capom=elmts(j,4)*deg
        omega=elmts(j,5)*deg
        capm=elmts(j,6)*deg
        gm=msun+mass(j)
        ialpha=-1
        call orbel_el2xv(gm,ialpha,sema,ecc,inc,capom,omega,capm,
     :    x,y,z,vx,vy,vz)
        write(*,8488) mass(j),rhill,radius
        write(*,8488) x,y,z
        write(*,8488) vx,vy,vz
      end do

c Jupiter
      sema=5.202d0
      mass_=0.2825345909524226d-06/0.2959122082855911d-03*msun
      ecc=0.056d0
      inc=0.288d0/180.d0*dpi
      rho=1.33d3
      capom=ran3(iseed)*2.d0*dpi
      omega=ran3(iseed)*2.d0*dpi
      capm=ran3(iseed)*2.d0*dpi
      gm=msun+mass_
      ialpha=-1
      call orbel_el2xv(gm,ialpha,sema,ecc,inc,capom,omega,capm,
     &  x,y,z,vx,vy,vz)
      rhill=sema*(mass_/(3.d0*msun))**(1.d0/3.d0)
      radius=(mass_/msun*2.d30/(4.d0/3.d0*dpi*rho))**(1.d0/3.d0)/au
      write(*,8488) mass_,rhill,radius
      write(*,8488) x,y,z
      write(*,8488) vx,vy,vz

c Saturn
      sema=9.580d0
      mass_=0.8459715185680659d-07/0.2959122082855911d-03*msun
      ecc=0.033d0
      inc=0.958d0/180.d0*dpi
      rho=0.678d3
      capom=ran3(iseed)*2.d0*dpi
      omega=ran3(iseed)*2.d0*dpi
      capm=ran3(iseed)*2.d0*dpi
      gm=msun+mass_
      ialpha=-1
      call orbel_el2xv(gm,ialpha,sema,ecc,inc,capom,omega,capm,
     &  x,y,z,vx,vy,vz)
      rhill=sema*(mass_/(3.d0*msun))**(1.d0/3.d0)
      radius=(mass_/msun*2.d30/(4.d0/3.d0*dpi*rho))**(1.d0/3.d0)/au
      write(*,8488) mass_,rhill,radius
      write(*,8488) x,y,z
      write(*,8488) vx,vy,vz

      stop

990   continue
      write(*,*) 'Error reading iseed.'
      end

c ===============================================================
      function ran3(idum)
      implicit real*8(a-h,o-z)
      parameter (mbig=1000000000,mseed=161803398,mz=0,fac=1.d-9)
      dimension ma(55)
      data iff /0/
      save
c --------------------------------------------------------------------
      if((idum.ge.0).and.(iff.ne.0)) goto 20
        iff=1
        mj=mseed-iabs(idum)
        mj=mod(mj,mbig)
        ma(55)=mj
        mk=1
        do 11 i=1,54
          ii=mod(21*i,55)
          ma(ii)=mk
          mk=mj-mk
          if(mk.lt.mz)mk=mk+mbig
          mj=ma(ii)
11      continue
        do 13 k=1,4
          do 12 i=1,55
            ma(i)=ma(i)-ma(1+mod(i+30,55))
            if(ma(i).lt.mz)ma(i)=ma(i)+mbig
12        continue
13      continue
        inext=0
        inextp=31
        idum=1
20    continue
      inext=inext+1
      if(inext.eq.56)inext=1
      inextp=inextp+1
      if(inextp.eq.56)inextp=1
      mj=ma(inext)-ma(inextp)
      if(mj.lt.mz)mj=mj+mbig
      ma(inext)=mj
      ran3=mj*fac
      return
      end

